<?php
/*
Plugin Name: referrer
Description: sends referrer codes per email
Version: 0.1
Author: Darth Vader
*/

// Prevent direct access
if (!defined('ABSPATH')) {
    exit;
}

// Add action to handle form submission
add_action('wpcf7_mail_sent', 'handle_referral_form_submission');

function handle_referral_form_submission($contact_form) {
    $submission = WPCF7_Submission::get_instance();
    if ($submission) {
        $data = $submission->get_posted_data();
        $name = sanitize_text_field($data['your-name']);
        $email = sanitize_email($data['your-email']);
        
        // Generate a unique referral code
        $referral_code = generate_unique_referral_code();

        if ($referral_code) {
            // Send the referral code via email
            $subject = 'Your Referral Code';
            $message = "Hi $name,\n\nThank you for signing up. Your referral code is: $referral_code\n\nBest regards,\nYour Company";
            wp_mail($email, $subject, $message);

            // Store the data
            global $wpdb;
            $table_name = $wpdb->prefix . 'referral_codes';
            $wpdb->insert(
                $table_name,
                array(
                    'name' => $name,
                    'email' => $email,
                    'referral_code' => $referral_code,
                    'created_at' => current_time('mysql')
                )
            );
        }
    }
}

// generate unique ID in XXX-XXX form
function generate_uid($length = 6) {
    $characters = 'ABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789';
    $charactersLength = strlen($characters);
    $uid = '';
    for ($i = 0; $i < $length; $i++) {
        $uid .= $characters[rand(0, $charactersLength - 1)];
        if ($i == 2 && $length > 3) {
            $uid .= '-';
        }
    }
    return $uid;
}

// check if ID is really unique in database
function generate_unique_referral_code($length = 6) {
    global $wpdb;
    $table_name = $wpdb->prefix . 'referral_codes';
    $isUnique = false;
    $newCode = '';

    while (!$isUnique) {
        $newCode = generate_uid($length);

        $result = $wpdb->get_var($wpdb->prepare("SELECT COUNT(*) FROM $table_name WHERE referral_code = %s", $newCode));
        if ($result == 0) {
            $isUnique = true;
        }
    }

    return $newCode;
}

// Create the table to store referral codes
function create_referral_codes_table() {
    global $wpdb;
    $table_name = $wpdb->prefix . 'referral_codes';
    $charset_collate = $wpdb->get_charset_collate();
    
    $sql = "CREATE TABLE $table_name (
        id mediumint(9) NOT NULL AUTO_INCREMENT,
        name tinytext NOT NULL,
        email varchar(100) NOT NULL,
        referral_code varchar(36) NOT NULL,
        created_at datetime DEFAULT '0000-00-00 00:00:00' NOT NULL,
        PRIMARY KEY  (id),
        UNIQUE KEY referral_code (referral_code)
    ) $charset_collate;";
    
    require_once(ABSPATH . 'wp-admin/includes/upgrade.php');
    dbDelta($sql);
}

// Hook to create the table on plugin activation
register_activation_hook(__FILE__, 'create_referral_codes_table');
